%%% FIGURE 5 %%%
close all;
clear all;
clc;

%Load data for figure
load('Figures_5_S2.mat')

%Figure parameters
ms = 14;
lw = 1.5;

%% Fitting Single-Shell model to Heat-inactivated shells

cplxData=complex(RE2n_avg_Snv, IM2n_avg_Snv);

x0=[0.1    0.1     0.1    0.1    0.1   0.1  0.1];
lb=[0.01  0.01    0.01    0.01   0.01  0.01 0.01];
ub=[10     10      10      10    10    10   10];
global dataC
global f
dataC=cplxData;

options = psoptimset;
options = psoptimset(options,'TolMesh',1e-6);
options = psoptimset(options,'MaxIter',10000);
options = psoptimset(options,'UseParallel',1);
options = psoptimset(options,'MeshAccelerator','on');
options = psoptimset(options,'SearchMethod',[]);

f=fStore;
[x,fval,exitflag,output] = ...
    patternsearch(@fitDebyeRelaxationFn,x0,[],[],[],[],lb,ub,[],options);
xStore=x;

h1=figure(1);plot(log10(f),real(dataC),'k*','markersize',ms)
set(gca,'fontsize',20),set(gca,'linewidth',2),xlabel('Log_{10}(Frequency) (Hz)'),ylabel('\Re(Z)')
h2=figure(2);plot(log10(f),imag(dataC),'k*','markersize',ms)
set(gca,'fontsize',20),set(gca,'linewidth',2),xlabel('Log_{10}(Frequency) (Hz)'),ylabel('\Im(Z)')

f=10.^(5:0.02:8);
dataC=zeros(size(f));
[diff,fittedCplx]=fitDebyeRelaxationFn(x);
figure(1),hold on,plot(log10(f),real(fittedCplx),'k','linewidth',2)
figure(2),hold on,plot(log10(f),imag(fittedCplx),'k','linewidth',2)
pause(0.001)


%% Fitting Double-Shell model to Heat-inactivated oocysts

cplxData=complex(RE2n_avg_NV, IM2n_avg_NV);

x0=[0.1    0.1     0.1        0.1   0.1];
lb=[0.01  0.01  0.01    0.01  0.01];
ub=[10  10    10        10     10];
global dataC
global f
dataC=cplxData;

options = psoptimset;
options = psoptimset(options,'TolMesh',1e-6);
options = psoptimset(options,'MaxIter',10000);
options = psoptimset(options,'UseParallel',1);
options = psoptimset(options,'MeshAccelerator','on');
options = psoptimset(options,'SearchMethod',[]);

f=fStore;
[x,fval,exitflag,output] = ...
    patternsearch(@fitRelative_doubleshell,x0,[],[],[],[],lb,ub,[],options);
xStoreGran=x;

figure(9),plot(log10(f),real(dataC),'k*','markersize',ms)
set(gca,'fontsize',20),set(gca,'linewidth',2),xlabel('Log_{10}(Frequency) (Hz)'),ylabel('\Re(Z)'),title('(c)')
figure(10),plot(log10(f),imag(dataC),'k*','markersize',ms)
set(gca,'fontsize',20),set(gca,'linewidth',2),xlabel('Log_{10}(Frequency) (Hz)'),ylabel('\Im(Z)'),title('(d)')

f=10.^(5:0.02:8);
dataC=zeros(size(f));
[diff,fittedCplx]=fitRelative_doubleshell(x);
figure(9),hold on,plot(log10(f),real(fittedCplx),'k','linewidth',2)
ylim([0 0.25])

figure(10),hold on,plot(log10(f),imag(fittedCplx),'k','linewidth',2)
ylim([-.1 0])
pause(0.001)

%% Fitting Single-Shell model to Untreated shells

cplxData=complex(RE2n_avg_S, IM2n_avg_S);

x0=[0.1    0.1     0.1    0.1    0.1   0.1  0.1];
lb=[0.01  0.01    0.01    0.01   0.01  0.01 0.01];
ub=[10     10      10      10    10    10   10];
global dataC
global f
dataC=cplxData;

options = psoptimset;
options = psoptimset(options,'TolMesh',1e-6);
options = psoptimset(options,'MaxIter',10000);
options = psoptimset(options,'UseParallel',1);
options = psoptimset(options,'MeshAccelerator','on');
options = psoptimset(options,'SearchMethod',[]);

f=fStore;
[x,fval,exitflag,output] = ...
    patternsearch(@fitDebyeRelaxationFn,x0,[],[],[],[],lb,ub,[],options);
xStore=x;

h1=figure(1);plot(log10(f),real(dataC),'r*','markersize',ms)
set(gca,'fontsize',20),set(gca,'linewidth',2),xlabel('Log_{10}(Frequency) (Hz)'),ylabel('\Re(Z)'),title('(a)')
h2=figure(2);plot(log10(f),imag(dataC),'r*','markersize',ms)
set(gca,'fontsize',20),set(gca,'linewidth',2),xlabel('Log_{10}(Frequency) (Hz)'),ylabel('\Im(Z)'),title('(b)')

f=10.^(5:0.02:8);
dataC=zeros(size(f));
[diff,fittedCplx]=fitDebyeRelaxationFn(x);
figure(1),hold on,plot(log10(f),real(fittedCplx),'r','linewidth',2)
hleg=legend('HIP - Shells','HIP - Shells SSF','UTP - Shells','UTP - Shells SSF','location','southwest');
set(hleg,'fontsize',12)
ylim([0 0.25])
print('Figure5a','-dtiff','-r300')
figure(2),hold on,plot(log10(f),imag(fittedCplx),'r','linewidth',2)
hleg=legend('HIP - Shells','HIP - Shells SSF','UTP - Shells','UTP - Shells SSF','location','southwest');
set(hleg,'fontsize',12)
ylim([-0.1 0])
print('Figure5b','-dtiff','-r300')
pause(0.001)


%% Fitting Double-Shell model to Untreated oocysts

cplxData=complex(RE2n_avg_V, IM2n_avg_V);

x0=[0.1    0.1     0.1        0.1   0.1];
lb=[0.01  0.01  0.01    0.01  0.01];
ub=[10  10    10        10     10];
global dataC
global f
dataC=cplxData;

options = psoptimset;
options = psoptimset(options,'TolMesh',1e-6);
options = psoptimset(options,'MaxIter',10000);
options = psoptimset(options,'UseParallel',1);
options = psoptimset(options,'MeshAccelerator','on');
options = psoptimset(options,'SearchMethod',[]);

f=fStore;
[x,fval,exitflag,output] = ...
    patternsearch(@fitRelative_doubleshell,x0,[],[],[],[],lb,ub,[],options);
xStoreGran=x;

figure(9),plot(log10(f),real(dataC),'r*','markersize',ms)
set(gca,'fontsize',20),set(gca,'linewidth',2),xlabel('Log_{10}(Frequency) (Hz)'),ylabel('\Re(Z)')
figure(10),plot(log10(f),imag(dataC),'r*','markersize',ms)
set(gca,'fontsize',20),set(gca,'linewidth',2),xlabel('Log_{10}(Frequency) (Hz)'),ylabel('\Im(Z)')

f=10.^(5:0.02:8);
dataC=zeros(size(f));
[diff,fittedCplx]=fitRelative_doubleshell(x);
figure(9),hold on,plot(log10(f),real(fittedCplx),'r','linewidth',2)
hleg=legend('HIP - Oocysts','HIP - Oocysts DSF','UTP - Oocysts','UTP - Oocysts DSF','location','southwest');
set(hleg,'fontsize',12)
ylim([0 0.25])
print('Figure5c','-dtiff','-r300')
figure(10),hold on,plot(log10(f),imag(fittedCplx),'r','linewidth',2)
hleg=legend('HIP - Oocysts','HIP - Oocysts DSF','UTP - Oocysts','UTP - Oocysts DSF','location','southwest');
set(hleg,'fontsize',12)
ylim([-.1 0])
pause(0.001)
print('Figure5d','-dtiff','-r300')